<?php
declare(strict_types=1);

namespace BvBeJ\Providers;

use Illuminate\Support\Facades\DB;
use Illuminate\Support\ServiceProvider;
use BvBeJ\Commands\ApolloConfigSync;
use BvBeJ\Handles\Apollo\Client;
use BvBeJ\Handles\BvBeJHandle;
use Illuminate\Database\Schema\Blueprint;


class BvBeJServiceProvider extends ServiceProvider
{
    /**
     * Bootstrap the application services.
     *
     * @return void
     */
    public function boot()
    {
        $this->publishes([
            realpath(__DIR__ . '/../../config/apollo.php') => config_path('apollo.php')
        ]);
        if ($this->app->runningInConsole()) {
            $this->commands([
                ApolloConfigSync::class
            ]);
        }

        Blueprint::macro('comment', function ($comment) {
            $this->charset =  DB::connection()->getConfig('charset') . " COMMENT='{$comment}'";
        });
    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->app->singleton('BvBeJ', function () {
            return new BvBeJHandle();
        });
        $this->app->singleton('BvBeJApollo', function () {
            return new Client(config('apollo'));
        });
    }
}
